@@ -26,6 +26,11 @@ sub rapidApp { (shift)->model("RapidApp"); }
 
 has 'request_id' => ( is => 'ro', default => sub { (shift)->rapidApp->requestCount; } );
 
+sub mount_url {
+  my $c = shift;
+  try{ $c->req->env->{SCRIPT_NAME} } || ''
+}
+
 # ---
 # Override dump_these to limit the depth of data structures which will get
 # dumped. This is needed because RapidApp has a relatively large footprint
@@ -65,6 +70,15 @@ around 'dump_these' => sub {
 # ---
 
 
+before 'setup_middleware' => sub {
+  my $c = shift;
+  
+  unshift @{ $c->config->{'psgi_middleware'} ||= [] },
+    '+RapidApp::Plack::Middleware'
+};
+
+
+
 around 'setup_components' => sub {
 	my ($orig, $app, @args)= @_;
   
